@@ -1,11 +1,14 @@
 import logging
 
 
-def setup_environment(code_bucket, download_settings=True) -> None:
+def setup_environment(
+    code_bucket, download_settings=True, verbose=False
+) -> None:
     """
     Initialize the Django ORM environment.
     :param code_bucket: the S3 bucket where the code and settings are stored.
     :param download_settings: whether to download the settings file from S3.
+    :param verbose: whether to log to the console.
     :return: None
     """
     import os
@@ -22,9 +25,12 @@ def setup_environment(code_bucket, download_settings=True) -> None:
         datefmt="[%X]",
         handlers=[RichHandler(console=Console(stderr=True))],
     )
-    log = logging.getLogger("rich")
+    log = logging.getLogger("preservation-database")
     log.setLevel(logging.INFO)
 
+    logging.getLogger("boto3").setLevel(logging.WARNING)
+    logging.getLogger("botocore").setLevel(logging.WARNING)
+
     current_directory = os.path.dirname(
         os.path.abspath(inspect.getfile(inspect.currentframe()))
     )
@@ -32,9 +38,10 @@ def setup_environment(code_bucket, download_settings=True) -> None:
     if download_settings:
         settings_file = Path(current_directory) / "downloaded_settings.py"
 
-        logging.info(
-            "Settings file downloading to: " "{}".format(settings_file)
-        )
+        if verbose:
+            logging.info(
+                "Settings file downloading to: " "{}".format(settings_file)
+            )
 
         import boto3
 
