@@ -444,7 +444,7 @@ def normalize_json_keys(json_obj: dict) -> dict:
             new_item = {}
 
             for key in item:
-                new_item[normalize_json_key(key)] = json_obj[key]
+                new_item[normalize_json_key(key)] = item[key]
 
             new_json_obj.append(new_item)
     else:
